import subprocess
import time
import requests
import json
import sys
from concurrent.futures import ThreadPoolExecutor

def run_flask_demo():
    """Run various requests against the Flask app."""
    base_url = "http://localhost:8000"
    
    print("\nTesting Flask endpoints...")
    
    # Test GET request
    response = requests.get(f"{base_url}/")
    print(f"GET / : {response.status_code}")
    
    # Test POST request with data
    user_data = {"name": "John Doe", "email": "john@example.com"}
    response = requests.post(
        f"{base_url}/users",
        json=user_data,
        headers={"Custom-Header": "test-value"}
    )
    print(f"POST /users : {response.status_code}")
    
    # Test error endpoint
    try:
        response = requests.get(f"{base_url}/error")
        print(f"GET /error : {response.status_code}")
    except Exception as e:
        print(f"Error endpoint test: {str(e)}")
    
    # Test slow endpoint
    response = requests.get(f"{base_url}/slow")
    print(f"GET /slow : {response.status_code} (took {response.elapsed.total_seconds():.2f}s)")

def run_fastapi_demo():
    """Run various requests against the FastAPI app."""
    base_url = "http://localhost:8000"
    
    print("\nTesting FastAPI endpoints...")
    
    # Similar tests as Flask...
    # (implement based on your FastAPI endpoints)

def run_python_demo():
    """Run the pure Python demo."""
    print("\nRunning pure Python demo...")
    subprocess.run([sys.executable, "sample_app/pure_python_app.py"])

def main():
    # Start Flask app in a separate process
    flask_process = subprocess.Popen(
        [sys.executable, "sample_app/flask_app.py"],
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE
    )
    
    # Give the servers time to start
    time.sleep(2)
    
    try:
        # Run demos
        run_flask_demo()
        run_python_demo()
        
    finally:
        # Clean up
        flask_process.terminate()
        flask_process.wait()

if __name__ == "__main__":
    main() 