from flask import Flask, jsonify, request
from sift_dev_logger.flask import instrument_logging_middleware
from sift_dev_logger.config import SiftDevConfig, configure
import time
import random

config = SiftDevConfig(
    service_name="flask-app",
    service_instance_id="flask-app-1",
    otlp_endpoint="http://88d1ef6c-3709-48b9-9441-399b323050f8.app.trysift.dev:5301",
    sift_dev_ingest_key="your-sift-dev-ingest-key",
)
configure(config)

app = Flask(__name__)

# Instrument logging middleware with default options.
instrument_logging_middleware(app)

def simulate_work():
    """Simulate processing time."""
    time.sleep(random.uniform(0.1, 0.5))

@app.route("/")
def index():
    simulate_work()
    return jsonify(message="Hello, Flask world!")

@app.route("/error")
def error():
    simulate_work()
    raise ValueError("This is a test error")

@app.route("/users", methods=['POST'])
def create_user():
    simulate_work()
    data = request.get_json()
    return jsonify(id=random.randint(1, 1000), **data), 201

@app.route("/users/<int:user_id>")
def get_user(user_id):
    simulate_work()
    if user_id < 100:
        return jsonify(id=user_id, name="Test User")
    return jsonify(error="User not found"), 404

@app.route("/slow")
def slow_response():
    time.sleep(2)  # Intentionally slow
    return jsonify(message="This was slow")

@app.route("/echo", methods=['POST'])
def echo():
    simulate_work()
    return jsonify(
        headers=dict(request.headers),
        json=request.get_json(),
        args=request.args.to_dict(),
    )

if __name__ == "__main__":
    # Run the Flask app on port 5000 with debug mode enabled.
    app.run(debug=True, port=8000) 