from typing import Optional
import os

class SiftDevConfig:
    def __init__(
        self,
        service_name: str = None,
        service_instance_id: str = None,
        otlp_endpoint: Optional[str] = None,
        sift_dev_ingest_key: Optional[str] = None,
        env: str = None,
        batch_delay_millis: int = 5000,
        capture_body: bool = False,
    ):
        self.service_name = service_name if service_name is not None else os.getenv("SIFT_DEV_SERVICE_NAME", "python-app")
        self.service_instance_id = service_instance_id if service_instance_id is not None else os.getenv("SIFT_DEV_SERVICE_INSTANCE_ID", "instance-1")
        self.otlp_endpoint = otlp_endpoint if otlp_endpoint is not None else os.getenv("OTLP_ENDPOINT")
        self.sift_dev_ingest_key = sift_dev_ingest_key if sift_dev_ingest_key is not None else os.getenv("SIFT_DEV_INGEST_KEY")
        self.env = env or os.getenv("SIFT_DEV_ENV", "unspecified")
        self.batch_delay_millis = batch_delay_millis
        self.capture_body = capture_body

_default_config: Optional[SiftDevConfig] = None

def configure(config: SiftDevConfig):
    global _default_config
    _default_config = config

def get_config() -> SiftDevConfig:
    global _default_config
    if _default_config is None:
        # Create a default configuration, using no OTLP configuration.
        _default_config = SiftDevConfig()
    return _default_config 